echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v curl) == "" ]] && echo "Installing curl" && extension --install curl && echo "Finished curl"
[[ $(command -v derb) == "" ]] && echo "Installing icu" && extension --install icu && echo "Finished icu"
[[ $(command -v xml2-config) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v qalc) == "" ]]; then
	echo "libqalculate" 								>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "libqalculate" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
